---
title: <span class="badge object-type-scalar"></span> ArcMinutes
---
# <span class="badge object-type-scalar"></span> ArcMinutes

Angle: Arc Minutes

## Definition

```python
# Angle: Arc Minutes
ArcMinutes: typing.Literal["arcmin"] = "arcmin"
```
